@@ -13,6 +13,7 @@ testfile4 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCD\MCD_
 testfile5 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCO\MCO_0.xlsx"
 testfile6 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_0.xlsx"
 testfile7 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXH\MCBXH_CopperWedges_0.xlsx"
+testfile8 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXH\MCBXH_CopperWedges_ThCool_0.xlsx"
 
 ledetFolder = 'C:\cernbox\LEDET\\'
 ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
@@ -20,9 +21,9 @@ ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
 def CompleteRun():
     start = time.time()
     a = ParametersLEDET()
-    a.readLEDETExcel(testfile7)
+    a.readLEDETExcel(testfile8)
     Sw = MinMaxSweep(a, 6)
-    MagnetName = 'MCBXH_CopperWedges'
+    MagnetName = 'MCBXH_CopperWedges_ThCool'
 
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
@@ -45,10 +46,14 @@ def CompleteRun():
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
     # Sw.addHeliumCrossSection(3, 6, basePoints=4)
 
-    ## MCBXH_CopperWedges
-    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.5, 2.5)
+    ## MCBXH_CopperWedges -1
+    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.3, 2.5)
     Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
-    Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
+    # Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
+
+    ## MCBXH_CopperWedges -2
+    Sw.addQuenchSweep("tStartQuench", [[1, 890],[121,1010],[289,1178],[393,1282],[1330,441],[1450,561],[1618,729],[1722,833]],
+                      [[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182]])
 
     Sw.generatePermutations()
     end = time.time()
@@ -59,12 +64,13 @@ def CompleteRun():
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCO\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MO_1AP\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCBXH_CopperWedges\\Input\\")
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCBXH_CopperWedges_ThCool\\Input\\")
 
     end = time.time()
     print("Time:", end - start)
     print("Preparation done")
 
-    # RunSimulations(ledetFolder, ledetExe, 'MCBXH_CopperWedges', RunSimulations=False)
+    # RunSimulations(ledetFolder, ledetExe, 'MCBXH_CopperWedges_ThCool', RunSimulations=False)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
     #                     'C:\\cernbox\\Validation_MCDO\\Exp Data\\RCO.A56B1_2018-03-16_PM_I_A_AutoAlign.csv',
     #                     Sw, Mat=False, SkipAlign=True)
@@ -79,9 +85,12 @@ def CompleteRun():
     # EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB1', 'MO_1AP',
     #                     'C:\\cernbox\\LHC-SM-API\\ROD_ROF\\ROD.A12B1_PM_I_A.csv',
     #                      Sw, Mat=False)
-    # EvaluateSimulations('C:\\cernbox\\LEDET\\LEDET\\MCBXH_CopperWedges\\Output\\Txt Files', 'MCBXH_CopperWedges',
+    # EvaluateSimulations('C:\\cernbox\\Validation_MCBX_HV\\LEDET Validation\\1st Sweep-RRR_fro_tQ\\Output\\Txt Files', 'MCBXH_CopperWedges',
     #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                      Sw, Mat=False)
+    EvaluateSimulations('C:\\cernbox\\Validation_MCBX_HV\\LEDET Validation\\2nd Sweep-RRR_fro_tQ_THCOOL\\Output\\Txt Files',
+                        'MCBXH_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
+                         Sw, Mat=False, showBestFit = 20)
 
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
