@@ -171,7 +171,7 @@ class ParametersCOSIM:
     def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
-                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0]):
+                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0], DistinctMagnets = 1):
 
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
@@ -378,6 +378,8 @@ class ParametersCOSIM:
 
         struct_total = []
         for n in range(0, N_LEDET):
+            if DistinctMagnets != 1:
+                DM = n+1
             for i in range(len(CoilSections)):  # Number of Ports
                 for j in range(2):  # 2Ports in PSpice
                     struct = {}
@@ -392,9 +394,9 @@ class ParametersCOSIM:
                                 cPPSpice = "V"
                             else:
                                 cPPSpice = couplingParameterPSpice[j][0][l][0]
-                            substruct_in["labels"] = [cPPSpice + "_field_" + str(i+n*len(CoilSections)+1) + "_stim"]  # First Port for Field
+                            substruct_in["labels"] = [cPPSpice + "_field_" + str(i+1) + "_stim"]  # First Port for Field
                         else:  # Second Port with circuit
-                            substruct_in["labels"] = ["V_circuit_" + str(i+n*len(CoilSections)+1) + "_stim"]
+                            substruct_in["labels"] = ["V_circuit_" + str(i+1) + "_stim"]
                         substruct_in["types"] = couplingParameterPSpice[j][0][l][1]
                         struct["inputs"].append(substruct_in)
 
@@ -408,9 +410,9 @@ class ParametersCOSIM:
                             else:
                                 cPPSpice = couplingParameterPSpice[j][1][k][0]
                             substruct_out["labels"] = [
-                                cPPSpice + "(x_mag_1." + Components[0] + "_" + str(i+n*len(CoilSections)+1) + ")"]
+                                cPPSpice + "(x_mag_" + str(DM)+ "." + Components[0] + "_" + str(i+1) + ")"]
                         else:
-                            substruct_out["labels"] = ["V(x_mag_1." + str(i+n*len(CoilSections)+1) + "_v_l_diff)"]
+                            substruct_out["labels"] = ["V(x_mag_" + str(DM)+ "." + str(i+1) + "_v_l_diff)"]
                         substruct_out["types"] = couplingParameterPSpice[j][1][k][1]
                         struct["outputs"].append(substruct_out)
 
